@@ -1,6 +1,7 @@
 import os
 import os.path
 from pathlib import Path
+from vint.linting.file_filter import find_vim_script
 
 
 def build_environment(cmdargs):
@@ -24,19 +25,6 @@ def _get_file_paths(cmdargs):
     if 'files' not in cmdargs:
         return []
 
-    found_files = _collect_files([Path(path) for path in cmdargs['files']])
-    return found_files
+    found_file_paths = find_vim_script(map(Path, cmdargs['files']))
 
-
-def _collect_files(paths):
-    result = set()
-    for path in paths:
-        if path.is_dir():
-            dir_path = path
-            result |= _collect_files(tuple(dir_path.iterdir()))
-
-        else:
-            file_path = path
-            result.add(file_path)
-
-    return result
+    return set(found_file_paths)
